"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const shell_1 = require("./shell");
function generateRunArgs(ctx, image, env = {}) {
    const environment = ctx.env.require('ENVIRONMENT');
    let runArgs = [
        'run',
        '--rm',
        '-v', `${ctx.codedir}:/usr/src/app`,
    ];
    if (environment !== 'DEVELOPMENT') {
        const sharedUserOpts = [
            '-u', `${process.getuid()}:${process.getgid()}`,
            '-v', '/etc/group:/etc/group:ro',
            '-v', '/etc/passwd:/etc/passwd:ro',
        ];
        runArgs = runArgs.concat(sharedUserOpts);
    }
    runArgs.push(image);
    for (let [k, v] of Object.entries(env)) {
        runArgs.push('-e');
        runArgs.push(`${k}=${v}`);
    }
    return runArgs;
}
exports.generateRunArgs = generateRunArgs;
async function prettyUserCommand(ctx, image, args, env = {}) {
    const actualArgs = args.map(arg => typeof arg === 'string' ? arg : arg[0]);
    const visualArgs = args.map(arg => {
        if (typeof arg === 'string') {
            return arg;
        }
        const [, visual] = arg;
        return visual;
    });
    const argv = shell_1.prettyArgv(visualArgs);
    ctx.userlog.info(`$ ${argv}`);
    const runArgs = generateRunArgs(ctx, image, env);
    try {
        await shell_1.runcmd({ outlog: ctx.userlog }, 'docker', [...runArgs, ...actualArgs], { cwd: ctx.codedir });
    }
    catch (e) {
        ctx.userlog.error(chalk_1.default.red(`${argv} failed`));
        throw e;
    }
}
exports.prettyUserCommand = prettyUserCommand;
